##################################
BK Precision 9130B DC Power Supply
##################################

.. autoclass:: pymeasure.instruments.bkprecision.BKPrecision9130B
    :members:
    :show-inheritance:
